Class: Gitlab::QA::Component::Gitlab

Inherits:
Base
  • Object
show all
Extended by:
Forwardable
Defined in:
lib/gitlab/qa/component/gitlab.rb

Defined Under Namespace

Classes: Availability

Constant Summary collapse

DATA_SEED_PATH =
File.expand_path('../../../../support/data', __dir__)
TRUSTED_PATH =
'/etc/gitlab/trusted-certs'
SSL_PATH =
'/etc/gitlab/ssl'
DATA_PATH =
'/tmp/data-seeds'

Constants inherited from Base

Base::CERTIFICATES_PATH

Instance Attribute Summary collapse

Attributes inherited from Base

#additional_hosts, #airgapped_network, #docker, #environment, #logger, #network, #network_aliases, #ports, #volumes

Instance Method Summary collapse

Methods inherited from Base

#add_network_alias, #hostname, #image, #instance, #ip_address, #prepare_airgapped_network, #prepare_docker_container, #prepare_docker_image, #prepare_network, #prepare_runner_network, #restart, #start_instance, #tag, #teardown

Methods included from Scenario::Actable

#act, included

Constructor Details

#initialize ⇒ Gitlab

Returns a new instance of Gitlab.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/gitlab/qa/component/gitlab.rb', line 45

def initialize
  super

  @skip_availability_check = false
  @omnibus_gitlab_rails_env = {}
  @omnibus_configuration = Runtime::OmnibusConfiguration.new(Runtime::Scenario.omnibus_configuration)
  @cert_volumes = { "authority" => TRUSTED_PATH, "gitlab-ssl" => SSL_PATH }
  @seed_admin_token = Runtime::Scenario.seed_admin_token
  @seed_db = Runtime::Scenario.seed_db
  @skip_server_hooks = Runtime::Scenario.skip_server_hooks
  @secrets = []

  self.release = 'CE'
end

Instance Attribute Details

#authority_volume ⇒ Object (readonly)

Returns the value of attribute authority_volume.



20
21
22
# File 'lib/gitlab/qa/component/gitlab.rb', line 20

def authority_volume
  @authority_volume
end

#gitaly_tls ⇒ Object

Returns the value of attribute gitaly_tls.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def gitaly_tls
  @gitaly_tls
end

#name ⇒ Object



90
91
92
# File 'lib/gitlab/qa/component/gitlab.rb', line 90

def name
  @name ||= "gitlab-#{edition}-#{SecureRandom.hex(4)}"
end

#omnibus_configuration ⇒ Object (readonly)

Returns the value of attribute omnibus_configuration.



20
21
22
# File 'lib/gitlab/qa/component/gitlab.rb', line 20

def omnibus_configuration
  @omnibus_configuration
end

#omnibus_gitlab_rails_env ⇒ Object (readonly)

Returns the value of attribute omnibus_gitlab_rails_env.



20
21
22
# File 'lib/gitlab/qa/component/gitlab.rb', line 20

def omnibus_gitlab_rails_env
  @omnibus_gitlab_rails_env
end

#relative_path ⇒ Object



106
107
108
# File 'lib/gitlab/qa/component/gitlab.rb', line 106

def relative_path
  @relative_path ||= ''
end

#release ⇒ Object

Returns the value of attribute release.



20
21
22
# File 'lib/gitlab/qa/component/gitlab.rb', line 20

def release
  @release
end

#runner_network ⇒ Object

Returns the value of attribute runner_network.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def runner_network
  @runner_network
end

#secrets ⇒ Object

Returns the value of attribute secrets.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def secrets
  @secrets
end

#seed_admin_token ⇒ Object

Returns the value of attribute seed_admin_token.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def seed_admin_token
  @seed_admin_token
end

#seed_db ⇒ Object

Returns the value of attribute seed_db.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def seed_db
  @seed_db
end

#skip_availability_check ⇒ Object

Returns the value of attribute skip_availability_check.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def skip_availability_check
  @skip_availability_check
end

#skip_server_hooks ⇒ Object

Returns the value of attribute skip_server_hooks.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def skip_server_hooks
  @skip_server_hooks
end

#ssl_volume ⇒ Object (readonly)

Returns the value of attribute ssl_volume.



20
21
22
# File 'lib/gitlab/qa/component/gitlab.rb', line 20

def ssl_volume
  @ssl_volume
end

#tls ⇒ Object

Returns the value of attribute tls.



26
27
28
# File 'lib/gitlab/qa/component/gitlab.rb', line 26

def tls
  @tls
end

Instance Method Details

#address ⇒ Object



94
95
96
# File 'lib/gitlab/qa/component/gitlab.rb', line 94

def address
  "#{scheme}://#{hostname}#{relative_path}"
end

#create_key_file(env_key) ⇒ Object



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/gitlab/qa/component/gitlab.rb', line 240

def create_key_file(env_key)
  directory = ENV['CI_PROJECT_DIR'] || Dir.tmpdir
  unique_filename = "#{env_key.downcase}_#{Time.now.to_i}_#{rand(100)}"
  key_file_path = File.join(directory, unique_filename)

  File.open(key_file_path, 'w') do |file|
    file.write(ENV.fetch(env_key))
    file.fsync
  end

  File.chmod(0o744, key_file_path)
  @volumes[key_file_path] = key_file_path

  key_file_path
end

#delete_key_file(path) ⇒ Object



256
257
258
# File 'lib/gitlab/qa/component/gitlab.rb', line 256

def delete_key_file(path)
  FileUtils.rm_f(path)
end

#elastic_url=(url) ⇒ Object



82
83
84
# File 'lib/gitlab/qa/component/gitlab.rb', line 82

def elastic_url=(url)
  @environment['ELASTIC_URL'] = url
end

#exist?(image, tag) ⇒ Boolean

Returns:

  • (Boolean)


127
128
129
# File 'lib/gitlab/qa/component/gitlab.rb', line 127

def exist?(image, tag)
  docker.manifest_exists?("#{image}:#{tag}")
end

#gitlab_port ⇒ Object



102
103
104
# File 'lib/gitlab/qa/component/gitlab.rb', line 102

def gitlab_port
  tls ? ["443:443"] : ["80"]
end

#package_version ⇒ Object



235
236
237
238
# File 'lib/gitlab/qa/component/gitlab.rb', line 235

def package_version
  manifest = JSON.parse(read_package_manifest)
  manifest['software']['package-scripts']['locked_version']
end

#prepare ⇒ Object



114
115
116
117
118
119
# File 'lib/gitlab/qa/component/gitlab.rb', line 114

def prepare
  prepare_gitlab_omnibus_config
  copy_certificates

  super
end

#prepare_gitlab_omnibus_config ⇒ Object



131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/gitlab/qa/component/gitlab.rb', line 131

def prepare_gitlab_omnibus_config
  @omnibus_configuration.expand_config_template(self)
  
  set_license_mode
  set_qa_user_agent
  env = @omnibus_gitlab_rails_env.merge(
    {
      'GITLAB_ALLOW_SEPARATE_CI_DATABASE' => Runtime::Env.allow_separate_ci_database.to_s
    }
  )

  @omnibus_configuration << "gitlab_rails['env'] = #{env}"
end

#process_exec_commands ⇒ Object



212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/gitlab/qa/component/gitlab.rb', line 212

def process_exec_commands
  Support::ConfigScripts.add_git_server_hooks(docker, name) unless skip_server_hooks

  @docker.copy(name, DATA_SEED_PATH, DATA_PATH) if seed_admin_token || seed_db
  exec_commands << seed_admin_token_command if seed_admin_token
  exec_commands << seed_test_data_command if seed_db
  exec_commands << Runtime::Scenario.omnibus_exec_commands

  commands = exec_commands.flatten.uniq
  return if commands.empty?

  Runtime::Logger.info("Running exec_commands...")
  commands.each { |command| @docker.exec(name, command, mask_secrets: secrets) }
end

#pull ⇒ Object



121
122
123
124
125
# File 'lib/gitlab/qa/component/gitlab.rb', line 121

def pull
  docker.(**release.) if release.

  super
end

#rails_version ⇒ Object



227
228
229
230
231
232
233
# File 'lib/gitlab/qa/component/gitlab.rb', line 227

def rails_version
  manifest = JSON.parse(read_package_manifest)
  {
    sha: manifest['software']['gitlab-rails']['locked_version'],
    source: manifest['software']['gitlab-rails']['locked_source']['git']
  }
end

#reconfigure ⇒ Object



184
185
186
187
188
189
190
191
# File 'lib/gitlab/qa/component/gitlab.rb', line 184

def reconfigure
  setup_omnibus

  @docker.attach(name) do |line, _wait|
    # TODO, workaround which allows to detach from the container
    break if line.include?('gitlab Reconfigured!')
  end
end

#scheme ⇒ Object



98
99
100
# File 'lib/gitlab/qa/component/gitlab.rb', line 98

def scheme
  tls ? 'https' : 'http'
end

#set_accept_insecure_certs ⇒ Object



110
111
112
# File 'lib/gitlab/qa/component/gitlab.rb', line 110

def set_accept_insecure_certs
  Runtime::Env.accept_insecure_certs = 'true'
end

#set_formless_login_token ⇒ Object



60
61
62
63
64
# File 'lib/gitlab/qa/component/gitlab.rb', line 60

def 
  return if Runtime::Env..to_s.strip.empty?

  @omnibus_gitlab_rails_env['GITLAB_QA_FORMLESS_LOGIN_TOKEN'] = Runtime::Env.
end

#set_license_mode ⇒ Object



66
67
68
69
70
71
# File 'lib/gitlab/qa/component/gitlab.rb', line 66

def set_license_mode
  return unless Runtime::Env.gitlab_license_mode == 'test'

  @omnibus_gitlab_rails_env['GITLAB_LICENSE_MODE'] = 'test'
  @omnibus_gitlab_rails_env['CUSTOMER_PORTAL_URL'] = Runtime::Env.customer_portal_url
end

#set_qa_user_agent ⇒ Object

Sets GITLAB_QA_USER_AGENT as a Rail environment variable so that it can be used by GitLab to bypass features that can't be automated.



75
76
77
78
79
80
# File 'lib/gitlab/qa/component/gitlab.rb', line 75

def set_qa_user_agent
  return if Runtime::Env.gitlab_qa_user_agent.to_s.strip.empty?

  @omnibus_gitlab_rails_env['GITLAB_QA_USER_AGENT'] = Runtime::Env.gitlab_qa_user_agent
  secrets << Runtime::Env.gitlab_qa_user_agent
end

#start ⇒ Object

rubocop:disable Metrics/AbcSize



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/gitlab/qa/component/gitlab.rb', line 145

def start # rubocop:disable Metrics/AbcSize
  ensure_configured!

  docker.run(image: image, tag: tag) do |command|
    command << "-d"
    command << "--name #{name}"
    command << "--net #{network}"
    command << "--hostname #{hostname}"

    [*@ports, *gitlab_port].each do |mapping|
      command.port(mapping)
    end

    @volumes.to_h.merge(cert_volumes).each do |to, from|
      command.volume(to, from, 'Z')
    end

    command.volume(File.join(Runtime::Env.host_artifacts_dir, name, 'logs'), '/var/log/gitlab', 'Z')

    @environment.to_h.each do |key, value|
      command.env(key, value)
    end

    @network_aliases.to_a.each do |network_alias|
      command << "--network-alias #{network_alias}"
    end

    @additional_hosts.each do |host|
      command << "--add-host=#{host}"
    end
  end

  return unless runner_network

  Docker::Command.execute(
    "network connect --alias #{name}.#{network} --alias #{name}.#{runner_network} #{runner_network} #{name}"
  )
end

#teardown! ⇒ Object



260
261
262
263
264
# File 'lib/gitlab/qa/component/gitlab.rb', line 260

def teardown!
  log_pg_stats

  super
end

#wait_until_ready ⇒ Object



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/gitlab/qa/component/gitlab.rb', line 193

def wait_until_ready
  return if skip_availability_check

  availability = Availability.new(
    name,
    relative_path: relative_path,
    scheme: scheme,
    protocol_port: gitlab_port.first.to_i
  )

  Runtime::Logger.info("Waiting for GitLab to become healthy ...")

  if availability.check(Runtime::Env.gitlab_availability_timeout)
    Runtime::Logger.info("-> GitLab is available at `#{availability.uri}`!".bright)
  else
    abort '-> GitLab unavailable!'.red
  end
end